{ config, lib, pkgs, ... }:

# hydra user needs to be manually crated
# sudo -u hydra -s
# hydra-create-user $USERNAME --password $PASSWORD --role admin

# also for reference some other hydra configs:
# https://github.com/NixOS/nixos-org-configurations/blob/master/delft/hydra.nix
# https://gist.github.com/LnL7/fcd5c0bf772f2165a1ac40be6617d2f4

with lib;

mkIf (elem "hydra" config.machine.services) {
  # also take a look at ../conf/nix.nix
  nix.buildMachines = [
    {
      hostName = "localhost";
      system = "x86_64-linux";
      supportedFeatures = ["kvm" "nixos-test" "big-parallel" "benchmark"];
      maxJobs = 8;
    }
  ];

  services.hydra = {
    enable = true;
    hydraURL = "https://builder.ophanim.de"; # externally visible URL
    listenHost = "localhost";
    port = 3001;
    minimumDiskFree = 15;
    minimumDiskFreeEvaluator = 15;
    notificationSender = "hydra@mail.ophanim.de"; # e-mail of hydra service
    useSubstitutes = true;
    debugServer = false;
    extraConfig = ''
      max_output_size = 4294967296
      store_uri = file:///var/cache/hydra?secret-key=/secret/hydra_cache
      server_store_uri = https://cache.ophanim.de
      binary_cache_public_uri https://cache.ophanim.de
      upload_logs_to_binary_cache = true
    '';
  };
}
